@@ -65,6 +65,7 @@ extern bool minimal_mode;
 extern gint hidden_x, hidden_y, hidden_monitor;
 extern bool hidden_monitor_primary;
 bool check_version = false;
+extern int unformatted_history;
 string custom_title;
 
 MathFunction *f_answer;
@@ -282,6 +283,11 @@ void create_application(GtkApplication *app) {
 		CALCULATOR->v_i->setChanged(false);
 	}
 
+	if(unformatted_history == 1) {
+		unformatted_history = 2;
+		reload_history();
+	}
+
 	//reset
 	functions_window = NULL;
 	selected_function_category = _("All");
@@ -383,10 +389,13 @@ static void qalculate_activate(GtkApplication *app) {
 			hidden_x = -1;
 		}
 #ifdef _WIN32
-		gtk_window_present_with_time(GTK_WINDOW(gtk_builder_get_object(main_builder, "main_window")), GDK_CURRENT_TIME);
+		gtk_window_iconify(GTK_WINDOW(list->data));
+		while(gtk_events_pending()) gtk_main_iteration();
+		gtk_window_present_with_time(GTK_WINDOW(list->data), GDK_CURRENT_TIME);
 #endif
 		if(expressiontext) gtk_widget_grab_focus(expressiontext);
 		gtk_window_present_with_time(GTK_WINDOW(list->data), GDK_CURRENT_TIME);
+
 		return;
 	}
 
@@ -522,6 +531,8 @@ static gint qalculate_command_line(GtkApplication *app, GApplicationCommandLine
 			hidden_x = -1;
 		}
 #ifdef _WIN32
+		gtk_window_iconify(GTK_WINDOW(gtk_builder_get_object(main_builder, "main_window")));
+		while(gtk_events_pending()) gtk_main_iteration();
 		gtk_window_present_with_time(GTK_WINDOW(gtk_builder_get_object(main_builder, "main_window")), GDK_CURRENT_TIME);
 #endif
 		if(expressiontext) gtk_widget_grab_focus(expressiontext);
